@@ -1,19 +1,8 @@
 /*
- *   Copyright (C) 2019 Kai Uwe Broulik <kde@privat.broulik.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 3 of
- *   the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@privat.broulik.de>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "pluginmanager.h"
 
@@ -81,9 +70,9 @@ bool PluginManager::setPluginLoaded(AbstractBrowserPlugin *plugin, bool loaded)
     plugin->setLoaded(loaded);
 
     if (loaded) {
-        emit pluginLoaded(plugin);
+        Q_EMIT pluginLoaded(plugin);
     } else {
-        emit pluginUnloaded(plugin);
+        Q_EMIT pluginUnloaded(plugin);
     }
 
     return true;
